﻿vatModule.controller('VatPreviewJournalController', ['$rootScope', '$scope', '$log', '$filter', '$translate', '$timeout', 'SweetAlert', '$q', 'uiGridConstants', '$interval', 'vatPreviewService', 'browserService', 'vatSessionService', 'region', 'enums', 'vatExportService',
    function ($rootScope, $scope, $log, $filter, $translate, $timeout, SweetAlert, $q, uiGridConstants, $interval, vatPreviewService, browserService, vatSessionService, region, enums, vatExportService) {
        'use strict';

        $scope.startDate = new Date(vatSessionService.project.year, 0, 1);
        $scope.endDate = new Date(vatSessionService.project.year, 11, 31);
        $scope.dateFormat = $translate.instant('dateFormat4YearMonthDay');
        $scope.startMonth = vatSessionService.year * 100 + vatSessionService.month;
        $scope.endMonth = vatSessionService.year * 100 + vatSessionService.month;
        $scope.totalMoneyAmount = 0;
        $scope.totalTaxAmount = 0;
        $scope.pageSize = constant.vatPagesize;

        var minDate = [1, vatSessionService.project.year];
        // var minDate = moment().startOf('month').subtract(0, 'months');
        var maxDate = [12, vatSessionService.project.year];
        var setDate = [
            [vatSessionService.month, vatSessionService.project.year],
            [vatSessionService.month, vatSessionService.project.year]];

        $scope.monthList = [$translate.instant('Month01'),
            $translate.instant('Month02'),
            $translate.instant('Month03'),
            $translate.instant('Month04'),
            $translate.instant('Month05'),
            $translate.instant('Month06'),
            $translate.instant('Month07'),
            $translate.instant('Month08'),
            $translate.instant('Month09'),
            $translate.instant('Month10'),
            $translate.instant('Month11'),
            $translate.instant('Month12')
        ];

        //初始化期间
        var initPeriods = function () {
            var curMonth = new Date().getMonth() + 1;

            $scope.queryParams = {
                pageInfo: {},
                periodStart: '',
                periodEnd: '',
                orgId: '',
                segment3: null,
                segment3Name: null,
                segment5: null,
                segment5Name: null,
                segment6: null,
                segment6Name: null,
                description: null,
                containsAdjustmentRecord: null
            };
        };

        //从数据库中load数据
        var loadJournalEntryDataFromDB = function (pageIndex) {
            initJournalEntryPagination();
            $scope.curJournalEntryPage = pageIndex;

            //初始化查询信息
            $scope.queryParams.pageInfo = {
                totalCount: $scope.queryJournalEntryResult.pageInfo.totalCount,
                pageIndex: pageIndex,
                pageSize: $scope.queryJournalEntryResult.pageInfo.pageSize,
                totalPage: 0
            };
            $scope.getDataFromDatabase($scope.queryParams);
        };

        $scope.getDataFromDatabase = function (queryParams) {
            vatPreviewService.getJEDataForDisplay(queryParams).success(function (data) {
                if (data) {
                    // minDate = data.
                    var index = 1;
                    data.list.forEach(function (v) {
                        v.index = index++;
                    });
                    $scope.gridDataSource = data.list;
                    $scope.queryJournalEntryResult.pageInfo = data;
                    computeJournalEntryPage();
                    $scope.ledgerName = data.list[0].ledgerName;
                    $scope.currencyCode = data.list[0].currencyCode;
                    $scope.status = data.list[0].status;
                    $scope.importDate = $filter('date')(data.list[0].createTime, "yyyy-MM-dd HH:mm:ss");
                }
            });
        };


        //点击任意一页加载数据事件
        var loadIncomeInvoiceDataByPage = function (pageIndex) {
            loadJournalEntryDataFromDB(pageIndex);
        };

        //计算页数，创建分页栏
        var computeJournalEntryPage = function () {

            if ($scope.queryJournalEntryResult.pageInfo && $scope.queryJournalEntryResult.pageInfo.total > 0) {

                var totalPage = parseInt($scope.queryJournalEntryResult.pageInfo.total / $scope.pageSize);
                totalPage = $scope.queryJournalEntryResult.pageInfo.totalCount % $scope.pageSize == 0 ? totalPage : totalPage + 1;

                //计算本页记录数
                if ($scope.queryJournalEntryResult.pageInfo.pageNum === totalPage) {
                    $scope.curPageItemCount = $scope.queryJournalEntryResult.pageInfo.total % $scope.pageSize;
                } else {
                    $scope.curPageItemCount = $scope.pageSize;
                }

                $scope.queryJournalEntryResult.pageInfo.totalPage = totalPage;

                var createPage = $("#totalInvoicePage").createPage({
                    pageCount: totalPage,
                    current: $scope.curJournalEntryPage,
                    backFn: function (p) {
                        //单击回调方法，p是当前页码
                        loadIncomeInvoiceDataByPage(p);
                    }
                });

                $('#totalInvoicePage').css('display', 'inline-block');
            } else {
                //如果查询结果为0，则直接设置本页记录数为0
                $scope.curPageItemCount = 0;
                var createPage = $("#totalInvoicePage").createPage({
                    pageCount: 0,
                    current: $scope.curJournalEntryPage,
                    backFn: function (p) {
                        //单击回调方法，p是当前页码
                        loadIncomeInvoiceDataByPage(p);
                    }
                });

                $('#totalInvoicePage').css('display', 'inline-block');
            }
        };

        //初始化分页信息
        var initJournalEntryPagination = function () {
            $scope.queryJournalEntryResult = {
                list: [],
                pageInfo: {
                    totalCount: -1,
                    pageIndex: 1,
                    pageSize: constant.pagesize,
                    totalPage: 0,
                }
            }

            $scope.curJournalEntryPage = 1;
        };

        //将选择了的查询条件显示在grid上方
        var doDataFilter = function (removeData) {
            if ($scope.queryParams.periodStart > $scope.queryParams.periodEnd) {
                $scope.queryParams.periodEnd = $scope.queryParams.periodStart;
            }

            //设置需要去掉的查询条件的值为空
            if (!PWC.isNullOrEmpty(removeData)) {
                var removeItem = removeData.split("|");
                removeItem.forEach(function (v) {
                    $scope.queryParams[v] = null;

                    if ($scope.queryParams.segment3 === null) {
                        $scope.queryParams.segment3 = '';
                    }
                    if ($scope.queryParams.segment3Name === null) {
                        $scope.queryParams.segment3Name = '';
                    }
                    if ($scope.queryParams.segment5 === null) {
                        $scope.queryParams.segment5Name = '';
                    }
                    if ($scope.queryParams.segment6 === null) {
                        $scope.queryParams.segment6 = '';
                    }
                    if ($scope.queryParams.segment6Name === null) {
                        $scope.queryParams.segment6Name = '';
                    }
                    if ($scope.queryParams.description === null) {
                        $scope.queryParams.description = '';
                    }
                    if ($scope.queryParams.invoiceType === null) {
                        $scope.InvoiceType.selected = undefined;
                    }
                });
            }

            loadJournalEntryDataFromDB(1);
            if (!PWC.isNullOrEmpty($scope.criteriaList)) {
                if ($scope.criteriaList.length > 6) {
                    $scope.criteriaListFirstRow = $scope.criteriaList.slice(0, 6);
                    $scope.criteriaListSecondRow = $scope.criteriaList.slice(6, $scope.criteriaList.length);
                } else {
                    $scope.criteriaListFirstRow = $scope.criteriaList.slice(0, $scope.criteriaList.length);
                }

            }
            $('.filter-button').popover("hide");
        };

        //去掉所有的查询条件，重新load数据
        var doDataFilterReset = function () {
            $scope.queryParams = {
                pageInfo: {},
                periodStart: '',
                periodEnd: '',
                orgId: '',
                segment3: null,
                segment3Name: null,
                segment5: null,
                segment5Name: null,
                segment6: null,
                segment6Name: null,
                description: null,
                containsAdjustmentRecord: null
            };
            $scope.queryParams.periodStart = $scope.startMonth;
            $scope.queryParams.periodEnd = $scope.endMonth;
            $scope.queryParams.orgId = vatSessionService.project.organizationID;
            // loadJournalEntryDataFromDB(1);
            // $('.filter-button').popover("hide");
        };

        var prepareSummary = function () {
            // do something before show popover
        };

        //在popover打开时执行事件
        var showPopover = function () {
            $timeout(function () {
                initDatePickers();
            }, 500);
        };

        //初始化时间控件
        var initDatePickers = function () {
            //认证开始时间
            var ele1 = $("#certificationDateStart");
            ele1.datepicker({
                startDate: $scope.startDate,
                endDate: $scope.endDate,
                language: region,
                autoclose: true,//选中之后自动隐藏日期选择框
                clearBtn: true,//清除按钮
                todayBtn: false,//今日按钮
                format: $scope.dateFormat//日期格式，详见 http://bootstrap-datepicker.readthedocs.org/en/release/options.html#format
            });
            ele1.datepicker("setDate", $scope.queryParams.certificationDateStart);
            //认证结束时间
            var ele2 = $("#certificationDateEnd");
            ele2.datepicker({
                startDate: $scope.startDate,
                endDate: $scope.endDate,
                language: region,
                autoclose: true,//选中之后自动隐藏日期选择框
                clearBtn: true,//清除按钮
                todayBtn: false,//今日按钮
                format: $scope.dateFormat//日期格式，详见 http://bootstrap-datepicker.readthedocs.org/en/release/options.html#format
            })
            ele2.datepicker("setDate", $scope.queryParams.certificationDateEnd);
        };

        var downloadJE = function () {
            vatPreviewService.initExportJEData($scope.queryParams).success(function (data, status, headers) {
                if (status === 204) {
                    SweetAlert.warning("没有数据可以下载");
                    return;
                }
                vatExportService.exportToExcel(data, status, headers, '日记账信息');
            }).error(function () {
                SweetAlert.error($translate.instant('PleaseContactAdministrator'));
            });
        };


        (function initialize() {
            $log.debug('VatPreviewInputInvoiceController.ctor()...');
            $('#input-invoice-period-picker').focus(function () {
                $('.filter-button').popover("hide");
            });
            //初始化month-picker
            $('#input-invoice-period-picker').rangePicker({
                minDate: minDate,
                maxDate: maxDate,
                setDate: setDate,
                months: $scope.monthList,//['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
                ConfirmBtnText: $translate.instant('Confirm'),
                CancelBtnText: $translate.instant('ButtonCancel')
            })
                .on('datePicker.done', function (e, result) {
                    //开始月份
                    var startMonth = result[0][1] * 100 + result[0][0];
                    //结束月份
                    var endMonth = result[1][1] * 100 + result[1][0];
                    $scope.startMonth = startMonth;
                    $scope.endMonth = endMonth;

                    $scope.queryParams.periodStart = startMonth;
                    $scope.queryParams.periodEnd = endMonth;
                    loadJournalEntryDataFromDB(1);
                });


            $scope.gridOptions = {
                bindingOptions: {
                    dataSource: 'gridDataSource'
                }, 
                columns: [
                    // {caption: $translate.instant('ApprovalStatus'),dataField: "approvalStatus",width: 120},
                    // {caption: $translate.instant('Posting'), dataField: "postedStatus",width: 120},
                    {caption: $translate.instant('AccountingPeriod'), dataField: "period",width: 100},
                    {caption: $translate.instant('DocumentDate'), dataField: "accountingDate", dataType: "date", format: "yyyy-MM-dd",width: 100},
                    // {caption: $translate.instant('JournalSource'), dataField: "journalSource",width: 200},
                    // {caption: $translate.instant('JournalCategory'), dataField: "category",width: 200},
                    {caption: $translate.instant('JournalName'), dataField: "name",width: 200},
                    {caption: $translate.instant('DocumentNo'), dataField: "voucherNum",width: 200},
                    {caption: $translate.instant('Summary'), dataField: "description",width: 200},
                    {caption: $translate.instant('MainBodyDescription'), dataField: "segment1Name",width: 200},
                    {caption: $translate.instant('CostCenterDescription'), dataField: "segment2Name",width: 200},
                    {caption: $translate.instant('SubjectDescription'), dataField: "segment3Name",width: 200},
                    {caption: $translate.instant('AuxiliaryAccountDescription'), dataField: "segment4Name",width: 200},
                    {caption: $translate.instant('ProfitCenterDescription'), dataField: "segment5Name",width: 200},
                    {caption: $translate.instant('ProductManual'), dataField: "segment6Name",width: 200},
                    {caption: $translate.instant('ProjectInstruction'), dataField: "segment7Name",width: 200},
                    {caption: $translate.instant('InterCompanyDescription'), dataField: "segment8Name",width: 200},
                    {caption: $translate.instant('Alternate1Description'), dataField: "segment9Name",width: 200},
                    {caption: $translate.instant('Alternate2Description'), dataField: "segment10Name",width: 200},
                    {caption: $translate.instant('currency'), dataField: "journalCurrencyCode",width: 200},
                    {caption: $translate.instant('LocalCurrency'), dataField: "currencyCode",width: 200},
                    {
                        caption: $translate.instant('JournalDebitAmount'),
                        dataField: "accountedDr",
                        format: {type: 'fixedPoint', precision: 2},
                        width: 100
                    },
                    {
                        caption: $translate.instant('JournalCreditAmount'),
                        dataField: "accountedCr",
                        format: {type: 'fixedPoint', precision: 2},
                        width: 100
                    },
                    {
                        caption: $translate.instant('LocalCurrencyDebitAmount'),
                        dataField: "enteredDr",
                        format: {type: 'fixedPoint', precision: 2},
                        width: 150
                    },
                    {
                        caption: $translate.instant('LocalCurrencyCreditAmount'),
                        dataField: "enteredCr",
                        format: {type: 'fixedPoint', precision: 2},
                        width: 150
                    },
                    {caption: $translate.instant('CashFlowEntry'), dataField: "cfItem",width: 200},
                    {caption: $translate.instant('City'), dataField: "attribute1",width: 200},
                    {
                        caption: $translate.instant('TransactionDate'),
                        dataField: "attribute2",
                        dataType: "date",
                        format: "yyyy-MM-dd",
                        width: 100
                    },
                    {caption: $translate.instant('BankAccountNumber'), dataField: "attribute3",width: 200},
                    {caption: $translate.instant('BankSerialNumber'), dataField: "attribute4",width: 200},
                    {caption: $translate.instant('SupplierCode'), dataField: "attribute5",width: 200},
                    {caption: $translate.instant('TransactionOrderNumber'), dataField: "attribute6",width: 200},
                    {caption: $translate.instant('SupplierName'), dataField: "attribute7",width: 200},
                    {caption: $translate.instant('ReceiveCode'), dataField: "attribute8",width: 200},
                    {caption: $translate.instant('PreparedBy'), dataField: "attribute9",width: 200},
                    {caption: $translate.instant('Reviewer'), dataField: "attribute10",width: 120},
                    {caption: $translate.instant('CostCenterDepartmentDescription1'), dataField: "attribute11",width: 120},
                    {caption: $translate.instant('CostCenterDepartmentDescription2'), dataField: "attribute12",width: 120},
                    {caption: $translate.instant('CostCenterDepartmentDescription3'), dataField: "attribute13",width: 120},
                    {caption: $translate.instant('CostCenterDepartmentDescription4'), dataField: "attribute14",width: 120},
                    {caption: $translate.instant('CostCenterDepartmentDescription5'), dataField: "attribute15",width: 120},
                    {caption: $translate.instant('CostCenterDepartmentDescription6'), dataField: "attribute16",width: 120}

                ],
                // onContentReady: function (e) {
                //     $scope.extractFinancialInstance = e.component;
                //     var totalCount = e.component.totalCount();
                //     if (totalCount > 0) {
                //         $scope.totalCount = totalCount;
                //     }
                // },
                allowColumnResizing: true,
                loadPanel: {
                    enabled: true
                },
                selection: {
                    mode: "single"
                },
                paging: {
                    pageSize: 50,
                },
                showBorders: true,
                showRowLines: true,
                showColumnLines: true,
                rowAlternationEnabled: true,  //单双行颜色
                hoverStateEnabled: true,
                noDataText: $translate.instant('NoDataText'),
            };

            $scope.doDataFilter = doDataFilter;
            $scope.doDataFilterReset = doDataFilterReset;
            $scope.prepareSummary = prepareSummary;
            $scope.showPopover = showPopover;
            $scope.downloadJE = downloadJE;

            initPeriods();
            initJournalEntryPagination();
            //初始化查询条件-期间范围
            $scope.queryParams.periodStart = vatSessionService.year * 100 + vatSessionService.month;
            $scope.queryParams.periodEnd = vatSessionService.year * 100 + vatSessionService.month;
            $scope.queryParams.orgId = vatSessionService.project.organizationID;
            if ($rootScope.currentLanguage === 'en-us') {
                $('.periodInput')[0].style.left = "280px";
            } else {
                $('.periodInput')[0].style.left = "150px";
            }
            loadJournalEntryDataFromDB(1);
        })();
    }
]);




